@@ -1,49 +1,59 @@
 
-###############################################################
-#                                                             #
-#       Original Splus: Ulric Lund                            #
-#       E-mail: ulund@calpoly.edu                             #
-#                                                             #
-###############################################################
+#############################################################
+#                                                           #
+#       Original Splus: Ulric Lund                          #
+#       E-mail: ulund@calpoly.edu                           #
+#                                                           #
+#############################################################
 
 #############################################################
 #                                                           #
 #   rao.test function                                       #
 #   Author: Claudio Agostinelli                             #
 #   E-mail: claudio@unive.it                                #
-#   Date: April, 12, 2005                                    #
-#   Version: 0.2                                            #
+#   Date: May, 31, 2006                                     #
+#   Version: 0.3-1                                          #
 #                                                           #
-#   Copyright (C) 2005 Claudio Agostinelli                  #
+#   Copyright (C) 2006 Claudio Agostinelli                  #
 #                                                           #
 #############################################################
 
 rao.test <- function(..., alpha = 0) {
-        y <- list(...)
-        x <- list()
-        for (i in 1:length(y)) {
-             if (is.data.frame(y[[i]])) {
-                 x <- c(x, as.list(y[[i]]))
-             } else if (is.matrix(y[[i]])) {
-                        for (j in 1:ncol(y[[i]])) {
-                             x <- c(x, list(y[[i]][,j]))
-                        }
-             } else if (is.list(y[[i]])) {
-                        x <- c(x, y[[i]])
-             } else {
-                 x <- c(x, list(y[[i]]))
-             }
-        }
-        if (length(x)<2) stop("There must be at least two samples")
-        for (i in 1:length(x)) {
-             x[[i]] <- as.circular(x[[i]])
-             x[[i]] <- conversion.circular(x[[i]], units="radians")
-             attr(x[[i]], "circularp") <- attr(x[[i]], "class") <- NULL
-        }
-        if (!any(c(0, 0.01, 0.025, 0.05, 0.1, 0.15)==alpha)) stop("'alpha' must be one of the following values: 0, 0.01, 0.025, 0.05, 0.1, 0.15")
+    y <- list(...)
+    x <- list()
+    for (i in 1:length(y)) {
+       if (is.data.frame(y[[i]])) {
+          x <- c(x, as.list(y[[i]]))
+       } else if (is.matrix(y[[i]])) {
+                 for (j in 1:ncol(y[[i]])) {
+                    x <- c(x, list(y[[i]][,j]))
+                 }
+               } else if (is.list(y[[i]])) {
+                         x <- c(x, y[[i]])
+               } else {
+                   x <- c(x, list(y[[i]]))
+               }
+    }
+    if (length(x)<2)
+       stop("There must be at least two samples")
+    for (i in 1:length(x)) {
+       x[[i]] <- conversion.circular(x[[i]], units="radians", zero=0, rotation="counter", modulo="2pi")
+       attr(x[[i]], "circularp") <- attr(x[[i]], "class") <- NULL
+    }
+    if (!any(c(0, 0.01, 0.025, 0.05, 0.1, 0.15)==alpha))
+       stop("'alpha' must be one of the following values: 0, 0.01, 0.025, 0.05, 0.1, 0.15")
 
     # Handling missing values
     x <- lapply(x, na.omit)
+
+    result <- RaoTestRad(x)
+    result$call <- match.call()
+    result$alpha <- alpha
+    class(result) <- "rao.test"
+    return(result)
+}
+
+RaoTestRad <- function(x) {
     n <- unlist(lapply(x, length))
     k <- length(x)
     c.data <- lapply(x, cos)
@@ -61,10 +71,11 @@ rao.test <- function(..., alpha = 0) {
     H.polar <- sum(tan^2/s.polar) - (sum(tan/s.polar))^2/sum(1/s.polar)
     U <- x^2 + y^2
     s.disp <- 4/n * (x^2 * s.co + y^2 * s.ss + 2 * x * y * s.cs)
-    H.disp <- sum(U^2/s.disp) - (sum(U/s.disp))^2/sum(1/s.disp)
-        
-    result <- list(statistic=c(H.polar, H.disp), df=k-1, p.value=c((1 - pchisq(H.polar, k - 1)), (1 - pchisq(H.disp, k - 1))), alpha=alpha)
-    class(result) <- "rao.test"
+    H.disp <- sum(U^2/s.disp) - (sum(U/s.disp))^2/sum(1/s.disp)        
+    result <- list()
+    result$statistic <- c(H.polar, H.disp)
+    result$df <- k-1
+    result$p.value <- c((1 - pchisq(H.polar, k - 1)), (1 - pchisq(H.disp, k - 1)))
     return(result)
 }
 
