@@ -11,27 +11,28 @@
 #   rho.circular function                                   #
 #   Author: Claudio Agostinelli                             #
 #   E-mail: claudio@unive.it                                #
-#   Date: April, 11, 2005                                   #
-#   Version: 0.2                                            #
+#   Date: May, 26, 2006                                     #
+#   Version: 0.3-1                                          #
 #                                                           #
-#   Copyright (C) 2005 Claudio Agostinelli                  #
+#   Copyright (C) 2006 Claudio Agostinelli                  #
 #                                                           #
 #############################################################
 
 rho.circular <- function(x, na.rm=FALSE) {
-    if (na.rm) 
-        x <- x[!is.na(x)]
-    if (any(is.na(x))) {
-        warning("No observations (at least after removing missing values)")
-        return(NA)
-    }
+   if (na.rm) 
+       x <- x[!is.na(x)]
+   if (any(is.na(x))) {
+       warning("No observations (at least after removing missing values)")
+       return(NA)
+   }
+   x <- conversion.circular(x, units="radians")
+   RhoCircularRad(x)
+}
 
-    n <- length(x)
-    x <- as.circular(x)
-    x <- conversion.circular(x, units="radians")
-    
-    sinr <- sum(sin(x))
-    cosr <- sum(cos(x))
-    result <- sqrt(sinr^2 + cosr^2)/n
-    return(result)
+RhoCircularRad <- function(x) {
+   n <- length(x)   
+   sinr <- sum(sin(x))
+   cosr <- sum(cos(x))
+   result <- sqrt(sinr^2 + cosr^2)/n
+   return(result)
 }
